summaryrefslogtreecommitdiffstats
path: root/chrome/test/pyautolib
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-10 12:29:21 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-10 12:29:21 +0000
commite90c2256aed9c209b5a1cc5db4ef0975ab64490b (patch)
tree486c9924987a95ac33a0dc4f6054a678b717ef7c /chrome/test/pyautolib
parent987d99ce11821cfd4af42b3a718d1dbfe8587817 (diff)
downloadchromium_src-e90c2256aed9c209b5a1cc5db4ef0975ab64490b.zip
chromium_src-e90c2256aed9c209b5a1cc5db4ef0975ab64490b.tar.gz
chromium_src-e90c2256aed9c209b5a1cc5db4ef0975ab64490b.tar.bz2
autofill: Rename AutoFillProfile to AutofillProfile.
BUG=72758 TEST=existing unit_tests Review URL: http://codereview.chromium.org/6658030 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@77630 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/test/pyautolib')
-rw-r--r--chrome/test/pyautolib/pyauto.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/test/pyautolib/pyauto.py b/chrome/test/pyautolib/pyauto.py
index ca782be..e57df5d 100644
--- a/chrome/test/pyautolib/pyauto.py
+++ b/chrome/test/pyautolib/pyauto.py
@@ -1262,13 +1262,13 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
tab_index=tab_index, window_index=window_index)['page_translated'],
args=[tab_index, window_index])
- def FillAutoFillProfile(self, profiles=None, credit_cards=None,
+ def FillAutofillProfile(self, profiles=None, credit_cards=None,
tab_index=0, window_index=0):
"""Set the autofill profile to contain the given profiles and credit cards.
If profiles or credit_cards are specified, they will overwrite existing
profiles and credit cards. To update profiles and credit cards, get the
existing ones with the GetAutoFillProfile function and then append new
profiles to the list and call this function.
Args:
@@ -1321,19 +1321,19 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
pyauto_errors.JSONInterfaceError if the automation call returns an error.
"""
cmd_dict = { # Prepare command for the json interface
- 'command': 'FillAutoFillProfile',
+ 'command': 'FillAutofillProfile',
'tab_index': tab_index,
'profiles': profiles,
'credit_cards': credit_cards
}
self._GetResultFromJSONRequest(cmd_dict, windex=window_index)
- def GetAutoFillProfile(self, tab_index=0, window_index=0):
+ def GetAutofillProfile(self, tab_index=0, window_index=0):
"""Return the profile including all profiles and credit cards currently
saved as a list of dictionaries.
The format of the returned dictionary is described above in
FillAutoFillProfile. The general format is:
{'profiles': [list of profile dictionaries as described above],
'credit_cards': [list of credit card dictionaries as described above]}
@@ -1345,7 +1345,7 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
pyauto_errors.JSONInterfaceError if the automation call returns an error.
"""
cmd_dict = { # Prepare command for the json interface
- 'command': 'GetAutoFillProfile',
+ 'command': 'GetAutofillProfile',
'tab_index': tab_index
}
return self._GetResultFromJSONRequest(cmd_dict, windex=window_index)
@@ -1262,13 +1262,13 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
If profiles or credit_cards are specified, they will overwrite existing
profiles and credit cards. To update profiles and credit cards, get the
- existing ones with the GetAutoFillProfile function and then append new
+ existing ones with the GetAutofillProfile function and then append new
profiles to the list and call this function.
Args:
@@ -1321,19 +1321,19 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
saved as a list of dictionaries.
The format of the returned dictionary is described above in
- FillAutoFillProfile. The general format is:
+ FillAutofillProfile. The general format is:
{'profiles': [list of profile dictionaries as described above],
'credit_cards': [list of credit card dictionaries as described above]}